#' @importFrom assertthat assert_that
assertthat::assert_that

#' @importFrom assertthat is.date
assertthat::is.date

#' @importFrom assertthat is.count
assertthat::is.count
